# sciparse - Scientific Dataset parsing
[![Build](https://github.com/edmundsj/sciparse/actions/workflows/python-package-conda.yml/badge.svg)](https://github.com/edmundsj/sciparse/actions/workflows/python-package-conda.yml) [![docs](https://github.com/edmundsj/sciparse/actions/workflows/build-docs.yml/badge.svg)](https://github.com/edmundsj/sciparse/actions/workflows/build-docs.yml) [![codecov](https://codecov.io/gh/edmundsj/sciparse/branch/main/graph/badge.svg?token=KS3FB8KS3Z)](https://codecov.io/gh/edmundsj/sciparse)



## Getting Started

## Features

## Common Issues

## How to Use
### Adding Additional Unit Tests
- Any time you want to add additional unit tests just add them to those in the
``tests/`` directory and prepend with the name ``test``. These will be
automatically found by pytest and run during local commits and remote builds.

### Writing the Documentation
- The documentation source is located in ``docs/source`` and is written in
restructured text (markdown is also available).

### Building the Documentation
Simply run ``make html`` from the ``docs/`` directory. This will compile the
files in the ``docs/source/`` directory, and place them in the main ``docs/``
directory where github pages can find them.

## Dependencies / Technologies Used
- [Sphinx](http://www.sphinx-doc.org/)
- [pytest](https://docs.pytest.org/en/stable/index.html)
- [Github Actions](https://github.com/features/actions)
- [Codecov](https://codecov.io/)
- [Github Pages](https://pages.github.com/)

## Acknowledgements
Thanks to all the great people on stack overflow and github, for their
seemingly boundless tolerance to my and others' questions. 
